##  Diagram Template Permissions
Diagram templates use a permission set separate from diagram and fact sheet shape permissions. By default, only administrators have access and can create, edit, delete, and generate diagrams from templates. All other roles start without access to diagram templates. Administrators can explicitly grant access to users in other roles.
For more information, see [Custom User Roles](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__custom_user_roles).
Permission | Description
---|---
Read | View diagram templates and their details, including previews.
Create | Create new diagram templates.
Update | Edit existing diagram templates in the template editor.
Delete | Delete diagram templates.
Unlock | Unlock templates that are locked for editing.
Change owner | Change the user who owns a diagram template.
Generate | Create diagrams from templates.


